@@ -1,7 +1,7 @@
 # Importing flask module in the project is mandatory
 # An object of Flask class is our WSGI application.
 from flask import Flask, request
-from external import configure
+from external import Kable
 
 # Flask constructor takes the name of
 # current module (__name__) as argument.
@@ -18,7 +18,7 @@ app = Flask(__name__)
 #     "baseUrl": "someUrl"
 # })
 
-kable = configure({
+kable = Kable({
     "client_id": 'kci_75bfe76dea214218be408fe6fa241f07',
     "client_secret": 'sk_test.jjrhHXZL.XdSSvBt22dKQdmMvjpiQ9F9v1DGtw26h',
     "environment": 'TEST',
@@ -27,10 +27,20 @@ kable = configure({
 })
 
 
-@app.route('/')
-@kable.authenticate
-def hello_world():
-    return "hello world"
+@app.route('/authenticateRequest')
+@kable.authenticateRequest
+def authenticated():
+    return "hello world - authenticate request"
+
+@app.route('/recordRequest')
+@kable.recordRequest
+def recorded():
+    return "hello world - recorded request"
+
+@app.route('/record')
+def recordData():
+    kable.record({"userId": "USER", "clientId": "PYTHONFLASK", "customerId": "FLASKPYTHON"})
+    return "hello world - record data"
 
 
 if __name__ == '__main__':
